u n i t o . i t - l'Università di Torino on line: u n i t o . i t - l'Università di Torino on line: Registrazione: Registrazione

# UNITO.it

[Vai al contenuto] [Vai alla Home Page]

## Scegli la visualizzazione

- Grafica
- Naviga senza grafica
- Mappa
- English
- 中文
- Intranet

## Strumenti di ricerca

Chiave di ricerca:
Ricerca avanzata Rubrica Tag Cloud

###

ATTENZIONE!!!
In seguito a segnalazioni di mancata ricezione delle mail di registrazione da parte di indirizzi "Hotmail", "msn" e "live", vi invitiamo a utilizzare altri domini di posta in fase di registrazione.

## Registrazione al Portale di Ateneo

Istruzioni Registration for foreign users

Nome: |  | Dato obbligatorio, inserire TUTTI i propri nomi
Cognome: |  | Dato obbligatorio, inserire TUTTI i propri cognomi
Password: |  | Dato obbligatorio, la password deve essere lunga almeno 8 caratteri e non può contenere caratteri al di fuori di alfanumerici (a-z,A-Z,0-9) e di !%+,-./:=
Conferma password: |
Sesso: | Maschio Femmina | Dato obbligatorio
Data di nascita: |  | Dato obbligatorio, formato data: gg/mm/aaaa
Nazione di nascita: |  | Dato obbligatorio
Comune di nascita: |  | Fornire la provincia e il comune di nascita (compilare solo se la nazione di nascita è Italia)
Nazione di cittadinanza: |  |
Codice fiscale: |  | Obbligatorio per utenti con nazionalità italiana
Numero di passaporto o di altro documento di identità: |  | Obbligatorio per utenti con nazionalità non italiana
Email: |  | Dato obbligatorio
Telefono cellulare | / | Dato non obbligatorio, max 17 caratteri (es. 0039 348 / 6767676)
Profilo: |  |
Autorizzazione utilizzo numero di telefono cellulare: | Desidero ricevere messaggi SMS istituzionali dall'Ateneo | L'autorizzazione non è obbligatoria
Presa visione informativa privacy: | INFORMATIVA AI SENSI DELL'ART. 13 del D. LGS. n. 193/2003 I dati personali forniti ai fini della registrazione sul Portale di Ateneo saranno acquisiti dall'Università degli Studi di Torino in qualità di Titolare del trattamento. Il conferimento dei dati è indispensabile per consentire l'accesso ai servizi offerti dall'Ateneo nonchè per rendere possibile la successiva immatricolazione ai corsi di studio, il trattamento dei dati è informatico. Qualora a seguito della registrazione si decidesse di non fruire dei servizi offerti dall'Ateneo, i dati personali acquisiti saranno conservati per un tempo massimo di 12 mesi, periodo che coincide con la scadenza delle credenziali provvisorie fornite a conclusione della preliminare fase di registrazione. Sui dati forniti in fase di registrazione è possibile esercitare i diritti previsti dall'art. 7 del D. Lgs. n. 196/2003, mediante richiesta da inoltrare via e-mail al Direttore del Portale di Ateneo all'indirizzo: sewi@unito.it - con oggetto: Diritti privacy. Se a seguito della registrazione si vorrà procedere con l'immatricolazione, i dati forniti saranno trattati per lo svolgimento delle attività istituzionali, nei limiti stabiliti dalle norme e nel rispetto dei principi generali di trasparenza, correttezza e riservatezza. In seguito all'immatricolazione verranno assegnate credenziali prive di scadenza che consentiranno l'accesso a tutti i servizi interni ed esterni (erogati da terzi che operano in collaborazione con l'Ateneo); inoltre, in tale fase verrà fornita un'ulteriore informativa inerente il trattamento dei dati trattati per la gestione della carriera studente. Le credenziali di autenticazione per l'accesso ai servizi devono essere mantenute riservate e conservate con la massima cura e diligenza e non devono mai essere condivise e/o cedute a terzi. L'invio esplicito e volontario di tutti i dati (ad esempio, l'indirizzo di posta elettronica fornito per l'invio delle credenziali di accesso, il numero di telefono fisso/mobile, ecc.) determina l'acquisizione dei dati da parte dell'Ateneo. Tali dati verranno utilizzati per rispondere alle richieste inoltrate dall'interessato e per la gestione della fase di registrazione nonchè, qualora si decida di immatricolarsi, per l'eventuale futura carriera dello studente nell'ambito delle finalità istituzionali proprie dell'Ateneo, cosí come previsto nell'art. 1 del Regolamento di Ateneo sul trattamento dei dati personali n. 146 del 2006. Il trattamento dei dati acquisiti sarà improntato ai principi di correttezza, di liceità e di trasparenza nel rispetto della disciplina in materia di riservatezza come indicato nel D. Lgs. n. 196/03. I dati, resi anonimi, potranno essere utilizzati per finalità statistiche. | Dato obbligatorio
Digita i caratteri visualizzati nell'immagine sottostante: |

- Riferimenti, contatti, PEC, reclami e segnalazioni
- Note legali
- Privacy
- Accessibilità
- In collaborazione con Cineca

Università degli Studi di Torino - Via Verdi, 8 - 10124 Torino - Centralino +39 011 6706111
P.I. 02099550010 - C.F. 80088230018 - IBAN IT07N0306909217100000046985
[Torna all'inizio del contenuto] [Torna al menu di navigazione]